@@ -1,58 +1,130 @@
 define(['base/js/namespace', 'jquery'], function (Jupyter, $) {
-  var add_bby_step_desc_cells = function () {
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`### 步骤标题`);
+  var insert_code_cell_below = function (code) {
+    Jupyter.notebook.insert_cell_below('code').set_text(code);
     Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+  };
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-desc
+  var insert_markdown_cell_below = function (md) {
+    Jupyter.notebook.insert_cell_below('markdown').set_text(md);
+    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+  };
+
+  var add_bby_step_desc_cells = function (type) {
+    insert_markdown_cell_below(`### 步骤标题 ${type}`);
+
+    insert_code_cell_below(`#platform-desc
 from ipyaliplayer import Player
 Player(vid='--替换你的视频id，上传地址 https://www.boyuai.com/elites/admin/public-video', aspect_ratio=4/3)
 `);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`<!--步骤描述 -->
-#### 【前言】
+    insert_markdown_cell_below(`<!--步骤描述 -->
+
+#### 知识点
 - 总结视频中的知识点
-#### 【练习】
-- 练习指导等内容
-#### 【练习目标】
-- 练习的教学目标
-`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+
+#### 代码练习说明
+- 代码练习题目说明
+
+#### 代码练习提示
+- 代码练习提示`);
   };
 
-  var add_bby_step_cells = function () {
-    add_bby_step_desc_cells();
+  var add_bby_string_step = function () {
+    add_bby_step_desc_cells('(String)');
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit
-# 学生实践代码
-`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+    insert_code_cell_below(`#platform-lock-hidden
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit-answer
-# 答案代码，为本步骤的答案，我们提供“一键填入”功能，将答案复制到对应的代码块中。
-# 所以建议 #platform-edit-answer 块是直接在 #platform-edit 块的基础上修改，并添加额外的解释说明。
-`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+# platform-lock-hidden 的代码不会展示，但会被运行
+
+def add(x):
+    return x + 1`);
+
+    insert_code_cell_below(`#platform-edit
+
+# platform-edit 可被学员编辑
+
+$$$`);
+
+    insert_code_cell_below(`#platform-edit-answer
+
+# 练习答案代码
+# 我们提供“一键填入”功能将答案复制到对应的代码块中
+# 建议 platform-edit-answer 块是直接在 platform-edit 块的基础上修改，并添加额外的解释说明
+
+x = add(0)`);
+    insert_code_cell_below(`#platform-lock
+
+# platform-lock 的代码会被展示和运行，无法修改
+print("add(0) =", x)`);
+
+    insert_markdown_cell_below(`add(0) = 1`);
   };
 
-  var add_bby_lesson_cells = function () {
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`## 课程标题`);
+  var add_bby_lesson = function () {
+    Jupyter.notebook.insert_cell_below('markdown').set_text(`## 单元标题
+
+单元简介（目前不展示这部分，所以可以写的简单一点）`);
     Jupyter.notebook.delete_cells();
-    // Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    add_bby_step_cells();
-    add_bby_step_cells();
+    add_bby_string_step();
   };
 
-  var add_turtle_cell = function () {
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-lock
+  var add_bby_verify_step = function () {
+    add_bby_step_desc_cells('(Verify)');
+
+    insert_code_cell_below(`#platform-edit
+
+def add(x):
+    return x`);
+
+    insert_code_cell_below(`#platform-edit-answer
+
+def add(x):
+    return x + 1`);
+
+    insert_code_cell_below(`#platform-lock
+print(add(1))`);
+    insert_code_cell_below(`#platform-verify
+import json
+if add(2) == 3 and add(-1) == 0: 
+    print(json.dumps({"result": True, "displayResult": "good"}))
+else:
+    print(json.dumps({"result": False, "displayResult": "bad"}))`);
+  };
+
+  var add_matplotlib_step = function () {
+    add_bby_step_desc_cells('(Matplotlib)');
+
+    insert_code_cell_below(`#platform-edit
+
+import matplotlib.pyplot as plt
+plt.plot([1, 2, 3])
+plt.show()`);
+
+    insert_code_cell_below(`#platform-edit-answer
+
+import matplotlib.pyplot as plt
+plt.plot([1, 2, 3, 4])
+plt.show()`);
+
+    insert_code_cell_below(`#platform-lock-hidden
+
+# 不要修改
+print("#matplotlib#")`);
+
+    insert_markdown_cell_below(`#matplotlib#`);
+  };
+
+  var add_turtle_step = function () {
+    add_bby_step_desc_cells('(Turtle)');
+
+    insert_code_cell_below(`#platform-lock
 from ipyturtle2 import TurtleWidget
 
 t = TurtleWidget()
 t`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit
+    insert_code_cell_below(`#platform-edit
 
 t.forward(100)
 t.left(90)
@@ -62,92 +134,20 @@ t.left(90)
 t.forward(100)
 t.left(90)
 t.forward(100)`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit-answer
+    insert_code_cell_below(`#platform-edit-answer
 
 t.forward(100)
 t.left(90)
 t.pencolor('blue')
 t.forward(100)`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-lock-hidden
+    insert_code_cell_below(`#platform-lock-hidden
+
+# 不要修改
 print("#turtle#")`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
 
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`#turtle#`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-  };
-
-  var add_matplotlib_cell = function () {
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit
-
-import matplotlib.pyplot as plt
-plt.plot([1, 2, 3])
-plt.show()`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit-answer
-
-import matplotlib.pyplot as plt
-plt.plot([1, 2, 3, 4])
-plt.show()`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-lock-hidden
-
-print("#matplotlib#")`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`#matplotlib#`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-  };
-
-  var add_string_verify_cell = function () {
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit
-
-print("123.")
-print("testing")
-print("lalala...")`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit-answer
-print("123")
-print("testing!")
-print("lalala....")`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('markdown').set_text(`123
-testing!
-lalala....`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-  };
-
-  var add_code_verify_cell = function () {
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit
-
-def add(x):
-    return x`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-edit-answer
-
-def add(x):
-    return x + 1`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-lock
-print(add(1))`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
-
-    Jupyter.notebook.insert_cell_below('code').set_text(`#platform-verify
-import json
-if add(2) == 3 and add(-1) == 0: # 替换为你需要的判断表达式
-    print(json.dumps({"result": True, "displayResult": "good"}))
-else:
-    print(json.dumps({"result": False, "displayResult": "bad"}))`);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+    insert_markdown_cell_below(`#turtle#`);
   };
 
   var quizString = `
@@ -234,14 +234,29 @@ quizzes.append({
 ipyquiz.QuizWidget(value=quizzes, quiz_id="__ipyquiz_quiz_id")
 `;
 
-  var add_quiz_cell = function () {
-    Jupyter.notebook.insert_cell_below('code').set_text(quizString);
-    Jupyter.notebook.select(Jupyter.notebook.get_selected_index() + 1);
+  var add_quiz_step = function () {
+    insert_markdown_cell_below(`### 步骤标题 (Quiz)`);
+
+    insert_code_cell_below(`#platform-desc
+from ipyaliplayer import Player
+Player(vid='--替换你的视频id，上传地址 https://www.boyuai.com/elites/admin/public-video', aspect_ratio=4/3)
+`);
+
+    insert_markdown_cell_below(`<!--步骤描述 -->
+
+#### 知识点
+- 总结视频中的知识点`);
+    insert_code_cell_below(quizString);
   };
 
-  var add_quiz_step = function () {
-    add_bby_step_desc_cells();
-    add_quiz_cell();
+  var add_file_upload_cell = function () {
+    insert_code_cell_below(`import os
+# basepath与惠楚确认
+basepath = os.path.expanduser('~/share/bby/')
+
+# 以下2选1, 请阅读波波鱼对接文档
+#os.chdir(basepath)
+#filepath = os.path.join(basepath, 'test.txt')`);
   };
 
   var addButtons = function () {
@@ -250,78 +265,66 @@ ipyquiz.QuizWidget(value=quizzes, quiz_id="__ipyquiz_quiz_id")
         {
           help: 'Add BBY Lesson',
           icon: 'fa-book',
-          handler: add_bby_lesson_cells,
+          handler: add_bby_lesson,
         },
-        'add-lesson-cells',
-        'ipybbycell'
-      ),
-      Jupyter.keyboard_manager.actions.register(
-        {
-          help: 'Add BBY Step',
-          icon: 'fa-map-pin',
-          handler: add_bby_step_cells,
-        },
-        'add-step-cells',
+        'add-lesson',
         'ipybbycell'
       ),
     ]);
     Jupyter.toolbar.add_buttons_group([
       Jupyter.keyboard_manager.actions.register(
         {
-          help: 'Add Turtle Cell',
-          icon: 'fa-pencil',
-          handler: add_turtle_cell,
-        },
-        'add-turtle-cell',
-        'ipybbycell'
-      ),
-      Jupyter.keyboard_manager.actions.register(
-        {
-          help: 'Add Matplotlib Cell',
-          icon: 'fa-area-chart',
-          handler: add_matplotlib_cell,
-        },
-        'add-matplotlib-cell',
-        'ipybbycell'
-      ),
-    ]);
-
-    Jupyter.toolbar.add_buttons_group([
-      Jupyter.keyboard_manager.actions.register(
-        {
-          help: 'Add String Verify',
+          help: 'Add BBY String Step',
           icon: 'fa-font',
-          handler: add_string_verify_cell,
+          handler: add_bby_string_step,
         },
-        'add-string-verify',
+        'add-string-step',
         'ipybbycell'
       ),
       Jupyter.keyboard_manager.actions.register(
         {
-          help: 'Add Code Verify',
-          icon: 'fa-code',
-          handler: add_code_verify_cell,
+          help: 'Add BBY Verify Step',
+          icon: 'fa-columns',
+          handler: add_bby_verify_step,
         },
-        'add-code-verify',
+        'add-verify-step',
         'ipybbycell'
       ),
-    ]);
-
-    Jupyter.toolbar.add_buttons_group([
       Jupyter.keyboard_manager.actions.register(
         {
-          help: 'Add Quiz Step',
+          help: 'Add BBY Matplotlib Step',
+          icon: 'fa-area-chart',
+          handler: add_matplotlib_step,
+        },
+        'add-matplotlib-step',
+        'ipybbycell'
+      ),
+      Jupyter.keyboard_manager.actions.register(
+        {
+          help: 'Add BBY Turtle Step',
+          icon: 'fa-pencil',
+          handler: add_turtle_step,
+        },
+        'add-turtle-step',
+        'ipybbycell'
+      ),
+      Jupyter.keyboard_manager.actions.register(
+        {
+          help: 'Add BBY Quiz Step',
           icon: 'fa-question-circle',
           handler: add_quiz_step,
         },
         'add-Quiz-Step',
         'ipybbycell'
       ),
+    ]);
+
+    Jupyter.toolbar.add_buttons_group([
       Jupyter.keyboard_manager.actions.register(
         {
-          help: 'Add Quiz Cell',
-          icon: 'fa-question-circle-o',
-          handler: add_quiz_cell,
+          help: 'Add BBY File Upload Cell',
+          icon: 'fa-upload',
+          handler: add_file_upload_cell,
         },
         'add-Quiz-Cell',
         'ipybbycell'
